@@ -1,6 +1,7 @@
 #! /bin/sh
 
-export PATH=/root/ccstools/kernel_test/:${PATH}
+cd ${0%/*}
+export PATH=$PWD:${PATH}
 
 echo "Testing all. (All results are reported)"
 newns sakura_filesystem_test
